@@ -4,19 +4,20 @@ import cPickle as pickle
 import zlib
 import logging
 from threading import Thread
-from tornado.options import options, define
+from tornado.options import options
 from collections import deque
 from zmq.eventloop.ioloop import ZMQPoller, IOLoop, PeriodicCallback
 from zmq.eventloop.zmqstream import ZMQStream
 from time import time
 from uuid import uuid4
 from traceback import format_exc
+from toto.options import safe_define
 
-define("worker_compression_module", type=str, help="The module to use for compressing and decompressing messages to workers. The module must have 'decompress' and 'compress' methods. If not specified, no compression will be used. Only the default instance will be affected")
-define("worker_serialization_module", type=str, help="The module to use for serializing and deserializing messages to workers. The module must have 'dumps' and 'loads' methods. If not specified, cPickle will be used. Only the default instance will be affected")
-define("worker_timeout", default=10.0, help="The default worker (instance()) will wait at least this many seconds before retrying a request (if retry is true), or timing out (if retry is false). Negative values will never retry or timeout. Note: This abs(value) is also the minimum resolution of any request-specific timeouts. Must not be 0.")
-define("worker_auto_retry", default=False, help="If True, the default timeout behavior of a worker RPC will be to retry instead of failing when the timeout is reached.")
-define("worker_address", default='', help="This is the address that toto.workerconnection.invoke(method, params) will send tasks too (As specified in the worker conf file). A comma separated list may be used to round-robin load balance tasks between workers.")
+safe_define("worker_compression_module", type=str, help="The module to use for compressing and decompressing messages to workers. The module must have 'decompress' and 'compress' methods. If not specified, no compression will be used. Only the default instance will be affected")
+safe_define("worker_serialization_module", type=str, help="The module to use for serializing and deserializing messages to workers. The module must have 'dumps' and 'loads' methods. If not specified, cPickle will be used. Only the default instance will be affected")
+safe_define("worker_timeout", default=10.0, help="The default worker (instance()) will wait at least this many seconds before retrying a request (if retry is true), or timing out (if retry is false). Negative values will never retry or timeout. Note: This abs(value) is also the minimum resolution of any request-specific timeouts. Must not be 0.")
+safe_define("worker_auto_retry", default=False, help="If True, the default timeout behavior of a worker RPC will be to retry instead of failing when the timeout is reached.")
+safe_define("worker_address", default='', help="This is the address that toto.workerconnection.invoke(method, params) will send tasks too (As specified in the worker conf file). A comma separated list may be used to round-robin load balance tasks between workers.")
 
 WORKER_SOCKET_CONNECT = 'CONNECT'
 WORKER_SOCKET_DISCONNECT = 'DISCONNECT'
@@ -61,7 +62,7 @@ class WorkerConnection(object):
     self.compress = compression and compression.compress or (lambda x: x)
     self.decompress = compression and compression.decompress or (lambda x: x)
 
-  def invoke(self, method, parameters, callback=None, timeout=0, auto_retry=None):
+  def invoke(self, method, parameters={}, callback=None, timeout=0, auto_retry=None):
     '''Invoke a ``method`` to be run on a remote worker process with the given ``parameters``. If specified, ``callback`` will be
        invoked with any response from the remote worker. By default the worker will timeout or retry based on the settings of the
        current ``WorkerConnection`` but ``timeout`` and ``auto_retry`` can be used for invocation specific behavior.
@@ -206,7 +207,7 @@ class WorkerInvocation(object):
     self._path = path
     self._connection = connection
 
-  def __call__(self, parameters, callback=None, timeout=0, auto_retry=None):
+  def __call__(self, parameters={}, callback=None, timeout=0, auto_retry=None):
     self._connection.invoke(self._path, parameters, callback, timeout, auto_retry)
 
   def __getattr__(self, path):
